@@ -6,7 +6,7 @@ from .ctc_decoder import *
 from .decorators import *
 from .dir_utils import *
 from .encodes import *
-from .imshow_utils import *
+from .image_utils import *
 from .lib_utils import *
 from .logging_utils import *
 from .lr_scheduler_utils import *
@@ -15,7 +15,7 @@ from .memory_utils import *
 from .minio_lib import *
 from .multi_label_utils import *
 from .np_utils import *
-from .opencv import *
+from .opencv_utils import *
 from .optimizers import *
 from .os_utils import *
 from .pickle_utils import *
@@ -25,4 +25,11 @@ from .resize_utils import *
 from .tensorboard_utils import *
 from .tf_utils import *
 from .color_utils import *
+from .gif_utils import *
+from .dict_named_tuple_utils import *
+from .dict_utils import *
+from .list_utils import *
+from .object_utils import *
+from .torch_utils import *
+from .shutil_utils import *
 from .utils import *
