@@ -1,7 +1,7 @@
 from enum import Enum
-from typing import Iterable, Sequence, Union
-
+from typing import Sequence, Union
 import numpy as np
+from deep_utils.utils.logging_utils.logging_utils import log_print, value_error_log
 
 
 class Point:
@@ -13,13 +13,13 @@ class Point:
 
     @staticmethod
     def point2point(
-        point,
-        in_source,
-        to_source,
-        in_relative=None,
-        to_relative=None,
-        shape=None,
-        shape_source=None,
+            point,
+            in_source,
+            to_source,
+            in_relative=None,
+            to_relative=None,
+            shape=None,
+            shape_source=None,
     ):
         if point is None or len(point) == 0:
             pass
@@ -50,13 +50,13 @@ class Point:
 
     @staticmethod
     def _point2point(
-        point,
-        in_source,
-        to_source,
-        in_relative=None,
-        to_relative=None,
-        shape=None,
-        shape_source=None,
+            point,
+            in_source,
+            to_source,
+            in_relative=None,
+            to_relative=None,
+            shape=None,
+            shape_source=None,
     ):
         if isinstance(in_source, Point.PointSource):
             in_source = in_source.value
@@ -64,30 +64,30 @@ class Point:
             to_source = to_source.value
 
         if (
-            in_source in [Point.PointSource.Torch.value,
-                          Point.PointSource.CV.value]
-            and to_source in [Point.PointSource.TF.value, Point.PointSource.Numpy.value]
+                in_source in [Point.PointSource.Torch.value,
+                              Point.PointSource.CV.value]
+                and to_source in [Point.PointSource.TF.value, Point.PointSource.Numpy.value]
         ) or (
-            in_source in [Point.PointSource.TF.value,
-                          Point.PointSource.Numpy.value]
-            and to_source in [Point.PointSource.Torch.value, Point.PointSource.CV.value]
+                in_source in [Point.PointSource.TF.value,
+                              Point.PointSource.Numpy.value]
+                and to_source in [Point.PointSource.Torch.value, Point.PointSource.CV.value]
         ):
             point = (point[1], point[0])
         elif (
-            (in_source is None and to_source is None)
-            or in_source == to_source
-            or (
-                in_source in [Point.PointSource.Torch.value,
-                              Point.PointSource.CV.value]
-                and to_source
-                in [Point.PointSource.CV.value, Point.PointSource.Torch.value]
-            )
-            or (
-                in_source in [Point.PointSource.TF.value,
-                              Point.PointSource.Numpy.value]
-                and to_source
-                in [Point.PointSource.TF.value, Point.PointSource.Numpy.value]
-            )
+                (in_source is None and to_source is None)
+                or in_source == to_source
+                or (
+                        in_source in [Point.PointSource.Torch.value,
+                                      Point.PointSource.CV.value]
+                        and to_source
+                        in [Point.PointSource.CV.value, Point.PointSource.Torch.value]
+                )
+                or (
+                        in_source in [Point.PointSource.TF.value,
+                                      Point.PointSource.Numpy.value]
+                        and to_source
+                        in [Point.PointSource.TF.value, Point.PointSource.Numpy.value]
+                )
         ):
             pass
         else:
@@ -109,14 +109,14 @@ class Point:
 
     @staticmethod
     def _put_point(
-        img,
-        point,
-        radius,
-        color=(0, 255, 0),
-        thickness=None,
-        lineType=None,
-        shift=None,
-        in_source="Numpy",
+            img,
+            point,
+            radius,
+            color=(0, 255, 0),
+            thickness=None,
+            lineType=None,
+            shift=None,
+            in_source="Numpy",
     ):
         import cv2
 
@@ -127,14 +127,14 @@ class Point:
 
     @staticmethod
     def put_point(
-        img,
-        point,
-        radius,
-        color=(0, 255, 0),
-        thickness=None,
-        lineType=None,
-        shift=None,
-        in_source="Numpy",
+            img,
+            point,
+            radius,
+            color=(0, 255, 0),
+            thickness=None,
+            lineType=None,
+            shift=None,
+            in_source="Numpy",
     ):
         if point is None or len(point) == 0:
             pass
@@ -185,17 +185,17 @@ class Box:
 
     @staticmethod
     def box2box(
-        box,
-        in_format=None,
-        to_format=None,
-        in_source=BoxSource.Numpy,
-        to_source=BoxSource.Numpy,
-        in_relative=None,
-        to_relative=None,
-        shape=None,
-        shape_source=None,
-        out_type=None,
-        return_int=None,
+            box,
+            in_format=None,
+            to_format=None,
+            in_source: Union[str, BoxSource] = BoxSource.Numpy,
+            to_source: Union[str, BoxSource] = BoxSource.Numpy,
+            in_relative=None,
+            to_relative=None,
+            shape=None,
+            shape_source=None,
+            out_type=None,
+            return_int=None,
     ):
         if box is None or len(box) == 0:
             pass
@@ -235,17 +235,18 @@ class Box:
 
     @staticmethod
     def _box2box(
-        box,
-        in_format=None,
-        to_format=None,
-        in_source=None,
-        to_source=None,
-        in_relative=None,
-        to_relative=None,
-        shape=None,
-        shape_source=None,
-        out_type=None,
-        return_int=None,
+            box,
+            in_format=None,
+            to_format=None,
+            in_source=None,
+            to_source=None,
+            in_relative=None,
+            to_relative=None,
+            shape=None,
+            shape_source: Point.PointSource = None,
+            out_type=None,
+            return_int=None,
+            logger=None
     ):
         """
 
@@ -254,10 +255,11 @@ class Box:
         :param to_format:
         :param in_source:
         :param to_source:
-        :param relative:
-        :param img_w:
-        :param img_h:
+        :param in_relative:
+        :param shape:
+        :param to_relative:
         :param out_type: output type of the box. Supported types: list, tuple, numpy
+        :param logger:
         :return:
         """
         if isinstance(in_format, Box.BoxFormat):
@@ -271,45 +273,45 @@ class Box:
             to_source = to_source.value
 
         if (
-            in_format == Box.BoxFormat.XYWH.value
-            and to_format == Box.BoxFormat.XYXY.value
+                in_format == Box.BoxFormat.XYWH.value
+                and to_format == Box.BoxFormat.XYXY.value
         ):
             x1, y1, w, h = box
             x2, y2 = x1 + w, y1 + h
             box = [x1, y1, x2, y2]
         elif (
-            in_format == Box.BoxFormat.XYXY.value
-            and to_format == Box.BoxFormat.XYWH.value
+                in_format == Box.BoxFormat.XYXY.value
+                and to_format == Box.BoxFormat.XYWH.value
         ):
             x1, y1, x2, y2 = box
             w, h = x2 - x1, y2 - y1
             box = [x1, y1, w, h]
         elif (
-            in_format == Box.BoxFormat.XYXY.value
-            and to_format == Box.BoxFormat.XCYC.value
+                in_format == Box.BoxFormat.XYXY.value
+                and to_format == Box.BoxFormat.XCYC.value
         ):
             x1, y1, x2, y2 = box
             w, h = x2 - x1, y2 - y1
             xc, yc = (x1 + x2) / 2, (y1 + y2) / 2
             box = [xc, yc, w, h]
         elif (
-            in_format == Box.BoxFormat.XCYC.value
-            and to_format == Box.BoxFormat.XYXY.value
+                in_format == Box.BoxFormat.XCYC.value
+                and to_format == Box.BoxFormat.XYXY.value
         ):
             xc, yc, w, h = box
             x1, y1, x2, y2 = xc - w / 2, yc - h / 2, xc + w / 2, yc + h / 2
             box = [x1, y1, x2, y2]
         elif (
-            in_format == Box.BoxFormat.XYWH.value
-            and to_format == Box.BoxFormat.XCYC.value
+                in_format == Box.BoxFormat.XYWH.value
+                and to_format == Box.BoxFormat.XCYC.value
         ):
             x1, y1, w, h = box
             x2, y2 = x1 + w, y1 + h
             xc, yc = (x1 + x2) / 2, (y1 + y2) / 2
             box = [xc, yc, w, h]
         elif (
-            in_format == Box.BoxFormat.XCYC.value
-            and to_format == Box.BoxFormat.XYWH.value
+                in_format == Box.BoxFormat.XCYC.value
+                and to_format == Box.BoxFormat.XYWH.value
         ):
             xc, yc, w, h = box
             x1, y1 = xc - w // 2, yc - h // 2
@@ -324,26 +326,26 @@ class Box:
             )
 
         if (
-            in_source in [Box.BoxSource.Torch.value, Box.BoxSource.CV.value]
-            and to_source in [Box.BoxSource.TF.value, Box.BoxSource.Numpy.value]
+                in_source in [Box.BoxSource.Torch.value, Box.BoxSource.CV.value]
+                and to_source in [Box.BoxSource.TF.value, Box.BoxSource.Numpy.value]
         ) or (
-            in_source in [Box.BoxSource.TF.value, Box.BoxSource.Numpy.value]
-            and to_source in [Box.BoxSource.Torch.value, Box.BoxSource.CV.value]
+                in_source in [Box.BoxSource.TF.value, Box.BoxSource.Numpy.value]
+                and to_source in [Box.BoxSource.Torch.value, Box.BoxSource.CV.value]
         ):
             box = [box[1], box[0], box[3], box[2]]
         elif (
-            (in_source is None and to_source is None)
-            or in_source == to_source
-            or (
-                in_source in [Box.BoxSource.Torch.value,
-                              Box.BoxSource.CV.value]
-                and to_source in [Box.BoxSource.CV.value, Box.BoxSource.Torch.value]
-            )
-            or (
-                in_source in [Box.BoxSource.TF.value,
-                              Box.BoxSource.Numpy.value]
-                and to_source in [Box.BoxSource.TF.value, Box.BoxSource.Numpy.value]
-            )
+                (in_source is None and to_source is None)
+                or in_source == to_source
+                or (
+                        in_source in [Box.BoxSource.Torch.value,
+                                      Box.BoxSource.CV.value]
+                        and to_source in [Box.BoxSource.CV.value, Box.BoxSource.Torch.value]
+                )
+                or (
+                        in_source in [Box.BoxSource.TF.value,
+                                      Box.BoxSource.Numpy.value]
+                        and to_source in [Box.BoxSource.TF.value, Box.BoxSource.Numpy.value]
+                )
         ):
             pass
         else:
@@ -351,16 +353,20 @@ class Box:
                 f"Conversion form {in_source} to {to_source} is not Supported."
                 f" Supported types: {Box._get_enum_names(Box.BoxSource)}"
             )
-        if to_source is not None and shape_source is not None and shape is not None:
-            img_w, img_h = Point.point2point(
-                shape, in_source=shape_source, to_source=to_source
-            )
-            if not in_relative and to_relative:
-                b1, b2, b3, b4 = box
-                box = [b1 / img_w, b2 / img_h, b3 / img_w, b4 / img_h]
-            elif in_relative and not to_relative:
-                b1, b2, b3, b4 = box
-                box = [b1 * img_w, b2 * img_h, b3 * img_w, b4 * img_h]
+        if in_relative != to_relative:
+            if to_source is not None and shape_source is not None and shape is not None:
+                img_w, img_h = Point.point2point(
+                    shape, in_source=shape_source, to_source=to_source
+                )
+                if not in_relative and to_relative:
+                    b1, b2, b3, b4 = box
+                    box = [b1 / img_w, b2 / img_h, b3 / img_w, b4 / img_h]
+                elif in_relative and not to_relative:
+                    b1, b2, b3, b4 = box
+                    box = [b1 * img_w, b2 * img_h, b3 * img_w, b4 * img_h]
+            else:
+                value_error_log(logger,
+                                "to_source, shape_source, and shape should contain values and should not be None")
 
         box = Box.get_type(box, out_type)
         if return_int:
@@ -383,18 +389,87 @@ class Box:
         return [n.name for n in in_]
 
     @staticmethod
-    def _put_box(
-        img,
-        box,
-        copy=False,
-        color=(0, 255, 0),
-        thickness=1,
-        lineType=None,
-        shift=None,
-        in_relative=False,
-        in_format="XYXY",
-        in_source="Numpy",
+    def _put_box_pil(img,
+                     box,
+                     outline="green",
+                     fill=None,
+                     in_relative=False,
+                     in_format="XYXY",
+                     in_source="Numpy",
+                     return_numpy=True):
+        from PIL import ImageDraw, Image
+        if isinstance(img, np.ndarray):
+            img = Image.fromarray(img)
+        box = Box.box2box(
+            box,
+            in_format=in_format,
+            to_format=Box.BoxFormat.XYXY,
+            in_source=in_source,
+            to_source=Box.BoxSource.Numpy,
+            in_relative=in_relative,
+            to_relative=False,
+            shape=img.size,
+            shape_source="Numpy",
+        )
+
+        shape = ((box[0], box[1]), (box[2], box[3]))
+        draw = ImageDraw.Draw(img)
+        draw.rectangle(shape, fill=fill, outline=outline)
+        if return_numpy:
+            np.array(img)
+        return img
+
+    @staticmethod
+    def put_box_pil(
+            img,
+            box,
+            outline="green",
+            fill=None,
+            in_relative=False,
+            in_format="XYXY",
+            in_source="Numpy",
+            return_numpy=True
     ):
+        if box is None or len(box) == 0:
+            pass
+        elif isinstance(box[0], (tuple, list, np.ndarray)):
+            for b in box:
+                img = Box._put_box_pil(
+                    img=img,
+                    box=b,
+                    outline=outline,
+                    fill=fill,
+                    in_relative=in_relative,
+                    in_format=in_format,
+                    in_source=in_source,
+                    return_numpy=return_numpy)
+        else:
+            img = Box._put_box_pil(
+                img=img,
+                box=box,
+                outline=outline,
+                fill=fill,
+                in_relative=in_relative,
+                in_format=in_format,
+                in_source=in_source,
+                return_numpy=return_numpy)
+
+        return img
+
+    @staticmethod
+    def _put_box(
+            img,
+            box,
+            copy=False,
+            color=(0, 255, 0),
+            thickness=1,
+            lineType=None,
+            shift=None,
+            in_relative=False,
+            in_format="XYXY",
+            in_source="Numpy",
+    ):
+
         import cv2
 
         box = Box.box2box(
@@ -429,16 +504,16 @@ class Box:
 
     @staticmethod
     def put_box(
-        img,
-        box,
-        copy=False,
-        color=(0, 255, 0),
-        thickness=1,
-        lineType=None,
-        shift=None,
-        in_relative=False,
-        in_format=BoxFormat.XYXY,
-        in_source=BoxSource.Numpy,
+            img,
+            box,
+            copy=False,
+            color=(0, 255, 0),
+            thickness=1,
+            lineType=None,
+            shift=None,
+            in_relative=False,
+            in_format=BoxFormat.XYXY,
+            in_source=BoxSource.Numpy,
     ):
         if box is None or len(box) == 0:
             pass
@@ -500,18 +575,52 @@ class Box:
             img_part = Box._get_box_img(img, bbox, box_format, box_source)
         return img_part
 
+    @staticmethod
+    def _put_text_pil(img, text, org, color=(0, 255, 0), font=None, font_size=32, return_np=True):
+        from PIL import Image, ImageFont, ImageDraw
+
+        if isinstance(img, np.ndarray):
+            img = Image.fromarray(img)
+        if isinstance(font, str):
+            font = ImageFont.truetype(font, font_size)
+
+        draw = ImageDraw.Draw(img)
+        draw.text(org, text, color, font=font)
+        if return_np:
+            img = np.array(img)
+        return img
+
+    @staticmethod
+    def put_text_pil(
+            img,
+            text,
+            org,
+            color=(0, 255, 0),
+            font=None,
+            font_size: int = 32,
+            return_np=True
+    ):
+        if text is None or len(text) == 0 or org is None or len(org) == 0:
+            pass
+        elif isinstance(text, (tuple, list, np.ndarray)):
+            for t, o in zip(text, org):
+                img = Box._put_text_pil(img, t, o, color, font, font_size, return_np)
+        else:
+            img = Box._put_text_pil(img, text, org, color, font, font_size, return_np)
+        return img
+
     @staticmethod
     def _put_text(
-        img,
-        text,
-        org,
-        fontFace=None,
-        fontScale=1,
-        color=(0, 255, 0),
-        thickness=1,
-        lineType=None,
-        bottomLeftOrigin=None,
-        org_source="Numpy",
+            img,
+            text,
+            org,
+            fontFace=None,
+            fontScale=1,
+            color=(0, 255, 0),
+            thickness=1,
+            lineType=None,
+            bottomLeftOrigin=None,
+            org_source="Numpy"
     ):
         import cv2
 
@@ -536,16 +645,16 @@ class Box:
 
     @staticmethod
     def put_text(
-        img,
-        text,
-        org,
-        fontFace=None,
-        fontScale: float = 1,
-        color=(0, 255, 0),
-        thickness=1,
-        lineType=None,
-        bottomLeftOrigin=None,
-        org_source="Numpy",
+            img,
+            text,
+            org,
+            fontFace=None,
+            fontScale: float = 1,
+            color=(0, 255, 0),
+            thickness=1,
+            lineType=None,
+            bottomLeftOrigin=None,
+            org_source="Numpy",
     ):
         if text is None or len(text) == 0 or org is None or len(org) == 0:
             pass
@@ -580,12 +689,12 @@ class Box:
 
     @staticmethod
     def get_biggest(
-        box,
-        in_format=BoxFormat.XYXY,
-        in_source=BoxSource.Numpy,
-        get_index=False,
-        inputs: Union[None, dict] = None,
-        reverse=False,
+            box,
+            in_format=BoxFormat.XYXY,
+            in_source=BoxSource.Numpy,
+            get_index=False,
+            inputs: Union[None, dict] = None,
+            reverse=False,
     ):
         if len(box) == 0 or box is None:
             return
@@ -646,7 +755,7 @@ class Box:
 
     @staticmethod
     def fill_outer_box(
-        img, box, value: int = 0, in_format=BoxFormat.XYXY, in_source=BoxSource.Numpy
+            img, box, value: int = 0, in_format=BoxFormat.XYXY, in_source=BoxSource.Numpy
     ):
         """
         Fill the outer area of the selected box with the specified value.
@@ -671,9 +780,74 @@ class Box:
         img = cv2.multiply(img, mask)
         return img
 
+    @staticmethod
+    def _put_box_text_pil(img, box, label, outline, text_color, text_font_size, text_font, return_numpy=True):
+        from PIL import ImageDraw, Image, ImageFont
+        if isinstance(img, np.ndarray):
+            pil_img = Image.fromarray(img)
+        else:
+            pil_img = img
+        if text_font is None:
+            pil_font = ImageFont.load_default()
+        elif isinstance(text_font, str):
+            pil_font = ImageFont.truetype(text_font, text_font_size)
+        p1, p2 = (int(box[0]), int(box[1])), (int(box[2]), int(box[3]))
+        pil_img = Box.put_box_pil(pil_img, [*p1, *p2], outline=outline, return_numpy=return_numpy)
+
+        draw_interface = ImageDraw.Draw(pil_img)
+        w, h = draw_interface.textsize(label, pil_font)
+        outside = p1[1] - h - 3 >= 0  # label fits outside box
+        p2 = p1[0] + w, (p1[1] - h - 3) if outside else (p1[1] + h + 3)
+        pil_img = Box.put_box_pil(pil_img, [*p1, *p2], outline=outline, fill=outline, return_numpy=return_numpy)
+
+        org = p1[0], (p1[1] - h - 2) if outside else (p1[1] + h + 2)
+
+        pil_img = Box.put_text_pil(pil_img, label, org, color=text_color, font_size=text_font_size, font=pil_font,
+                                   return_np=return_numpy)
+
+        img = np.array(pil_img) if return_numpy else pil_img
+        return img
+
+    @staticmethod
+    def put_box_text_pil(
+            img: Union[Sequence, np.ndarray],
+            box: Union[Sequence],
+            label: Union[Sequence, str],
+            outline=(128, 128, 128),
+            txt_color=(255, 255, 255),
+            text_font_size=32,
+            text_font=None,
+            return_numpy=True,
+            in_source=BoxSource.CV,
+    ):
+        box = Box.box2box(
+            box, in_source=in_source, to_source=Box.BoxSource.Numpy
+        )
+        if (
+                isinstance(box, Sequence)
+                and isinstance(box[0], Sequence)
+                and isinstance(label, Sequence)
+        ):
+            if isinstance(outline, Sequence) and isinstance(outline[0], Sequence):
+                if isinstance(txt_color, Sequence) and isinstance(txt_color[0], Sequence):
+                    for b, l, c, t_c in zip(box, label, outline, txt_color):
+                        img = Box._put_box_text_pil(img, b, l, c, t_c, text_font_size, text_font, return_numpy)
+                else:
+                    for b, l, c in zip(box, label, outline):
+                        img = Box._put_box_text_pil(img, b, l, c, txt_color, text_font_size, text_font,
+                                                    return_numpy)
+            else:
+                for b, l in zip(box, label):
+                    img = Box._put_box_text_pil(img, b, l, outline, txt_color, text_font_size, text_font,
+                                                return_numpy)
+        else:
+            img = Box._put_box_text_pil(img, box, label, outline, txt_color, text_font_size, text_font,
+                                        return_numpy)
+        return img
+
     @staticmethod
     def _put_box_text(
-        img, box, label, color=(128, 128, 128), txt_color=(255, 255, 255), thickness=2
+            img, box, label, color=(128, 128, 128), txt_color=(255, 255, 255), thickness=2
     ):
         import cv2
 
@@ -716,12 +890,12 @@ class Box:
 
     @staticmethod
     def put_box_text(
-        img: Union[Sequence, np.ndarray],
-        box: Union[Sequence],
-        label: Union[Sequence, str],
-        color=(128, 128, 128),
-        txt_color=(255, 255, 255),
-        thickness=2,
+            img: Union[Sequence, np.ndarray],
+            box: Union[Sequence],
+            label: Union[Sequence, str],
+            color=(128, 128, 128),
+            txt_color=(255, 255, 255),
+            thickness=2,
     ):
         """
         :param img:
@@ -736,13 +910,13 @@ class Box:
             box, in_source=Box.BoxSource.Numpy, to_source=Box.BoxSource.CV
         )
         if (
-            isinstance(box, Sequence)
-            and isinstance(box[0], Sequence)
-            and isinstance(label, Sequence)
+                isinstance(box, Sequence)
+                and isinstance(box[0], Sequence)
+                and isinstance(label, Sequence)
         ):
             if isinstance(color, Sequence) and isinstance(color[0], Sequence):
                 if isinstance(txt_color, Sequence) and isinstance(
-                    txt_color[0], Sequence
+                        txt_color[0], Sequence
                 ):
                     for b, l, c, t_c in zip(box, label, color, txt_color):
                         img = Box._put_box_text(img, b, l, c, t_c, thickness)
@@ -758,49 +932,3 @@ class Box:
             img = Box._put_box_text(
                 img, box, label, color, txt_color, thickness)
         return img
-
-
-# @staticmethod
-# def _put_box_text(img, box, label, color=(128, 128, 128), txt_color=(255, 255, 255), thickness=2):
-#     import cv2
-#     Box.put_box(img, box, color, thickness=thickness, lineType=cv2.LINE_AA)
-#     tf = max(thickness - 1, 1)  # font thickness
-#     w, h = cv2.getTextSize(label, 0, fontScale=thickness / 3, thickness=tf)[0]  # text width, height
-#
-#     outside = box[1] - h - 3 >= 0  # label fits outside box
-#     p2 = p1[0] + w, p1[1] - h - 3 if outside else p1[1] + h + 3
-#     img = cv2.rectangle(img, p1, p2, color, -1, cv2.LINE_AA)  # filled
-#     img = cv2.putText(img, label, (p1[0], p1[1] - 2 if outside else p1[1] + h + 2), 0, thickness / 3, txt_color,
-#                       thickness=tf, lineType=cv2.LINE_AA)
-#     return img
-#
-#
-# @staticmethod
-# def put_box_text(img: Union[Sequence, np.ndarray], box: Union[Sequence], label: Union[Sequence, str],
-#                  color=(128, 128, 128), txt_color=(255, 255, 255), thickness=2):
-#     """
-#
-#     :param img:
-#     :param box: It should be in numpy format
-#     :param label:
-#     :param color:
-#     :param txt_color:
-#     :param thickness:
-#     :return:
-#     """
-#     if isinstance(img, Iterable) and isinstance(box, Iterable) and isinstance(label, Iterable):
-#         if isinstance(color, Sequence) and isinstance(color[0], Sequence):
-#             if isinstance(txt_color, Sequence) and isinstance(txt_color[0], Sequence):
-#                 for b, l, c, t_c in zip(box, label, color, txt_color):
-#                     img = Box._put_box_text(img, b, l, c, t_c, thickness)
-#             else:
-#                 for b, l, c in zip(box, label, color):
-#                     img = Box._put_box_text(img, b, l, c, txt_color, thickness)
-#         else:
-#             for b, l in zip(box, label):
-#                 img = Box._put_box_text(img, b, l, color, txt_color, thickness)
-#     else:
-#         img = Box._put_box_text(img, box, label, color, txt_color, thickness)
-#     return img
-if __name__ == "__main__":
-    print(Box.BoxFormat.XYXY is Box.BoxFormat)
