@@ -3,8 +3,10 @@ MATPLOTLIB_COLORS = ["green", "orange", "blue", "black"]
 
 def show_plt(img, is_rgb, figsize=None):
     import matplotlib
-    matplotlib.use('TkAgg')
+
+    matplotlib.use("TkAgg")
     import matplotlib.pyplot as plt
+
     if not is_rgb:
         img = img[..., ::-1]
     plt.figure(figsize=figsize)
