@@ -11,11 +11,12 @@ import torch
 from tqdm import tqdm
 
 from deep_utils.main_abs import MainClass
-from deep_utils.utils.box_utils.boxes import Box, Point
-from deep_utils.utils.dir_utils.main import (
+from deep_utils.utils.box_utils.boxes import Box
+from deep_utils.utils.dir_utils.dir_utils import (
     dir_train_test_split,
     remove_create,
     transfer_directory_items,
+    file_incremental,
 )
 from deep_utils.utils.lib_utils.lib_decorators import (
     get_from_config,
@@ -24,9 +25,10 @@ from deep_utils.utils.lib_utils.lib_decorators import (
     out_shape_fix,
 )
 from deep_utils.utils.logging_utils import log_print
-from deep_utils.utils.opencv.main import show_destroy_cv2
+from deep_utils.utils.opencv_utils.main import show_destroy_cv2
 from deep_utils.utils.os_utils.os_path import split_extension
-from deep_utils.utils.utils import dictnamedtuple
+from deep_utils.utils.dict_named_tuple_utils import dictnamedtuple
+from deep_utils.utils.shutil_utils.shutil_utils import mv_or_copy
 
 from .config import Config
 
@@ -53,14 +55,14 @@ class OutputType:
 
 class YOLOV5TorchObjectDetector(MainClass):
     def __init__(
-        self,
-        class_names=None,
-        model_weight=None,
-        device="cpu",
-        img_size=(320, 320),
-        confidence=0.4,
-        iou_thresh=0.45,
-        **kwargs,
+            self,
+            class_names=None,
+            model_weight=None,
+            device="cpu",
+            img_size=(320, 320),
+            confidence=0.4,
+            iou_thresh=0.45,
+            **kwargs,
     ):
         super(YOLOV5TorchObjectDetector, self).__init__(
             name=self.__class__.__name__,
@@ -77,12 +79,12 @@ class YOLOV5TorchObjectDetector(MainClass):
 
     @staticmethod
     def yolo_resize(
-        img,
-        new_shape=(640, 640),
-        color=(114, 114, 114),
-        auto=True,
-        scaleFill=False,
-        scaleup=True,
+            img,
+            new_shape=(640, 640),
+            color=(114, 114, 114),
+            auto=True,
+            scaleFill=False,
+            scaleup=True,
     ):
 
         return letterbox(
@@ -106,15 +108,15 @@ class YOLOV5TorchObjectDetector(MainClass):
         print(f"{self.name}: weights are loaded")
 
     def detect_objects(
-        self,
-        img,
-        is_rgb,
-        class_indices=None,
-        confidence=None,
-        iou_thresh=None,
-        img_size=None,
-        agnostic=None,
-        get_time=False,
+            self,
+            img,
+            is_rgb,
+            class_indices=None,
+            confidence=None,
+            iou_thresh=None,
+            img_size=None,
+            agnostic=None,
+            get_time=False,
     ) -> Union[Type[OutputType], Dict[str, list]]:
         """
 
@@ -193,43 +195,49 @@ class YOLOV5TorchObjectDetector(MainClass):
         return output
 
     @staticmethod
-    def test_label(img_path, str_path):
+    def test_label_dir(dataset_dir, images_name="images", labels_name="labels"):
+        images_path = join(dataset_dir, images_name)
+        for name in sorted(os.listdir(images_path)):
+            img_address = join(images_path, name)
+            text_address = join(dataset_dir, labels_name, split_extension(name, '.txt'))
+            YOLOV5TorchObjectDetector.test_label(img_address, text_address)
+
+    @staticmethod
+    def test_label(img_path, label_path, show=True):
         import cv2
 
         img = cv2.imread(img_path)
         boxes, texts, orgs = [], [], []
-        with open(str_path, mode="r") as f:
+        with open(label_path, mode="r") as f:
             for line in f.readlines():
                 label, xc, yc, w, h = line.strip().split()
                 xc, yc, w, h = float(xc), float(yc), float(w), float(h)
                 boxes.append([xc, yc, w, h])
                 texts.append(f"label: {label}")
-                org = Point.point2point(
-                    (xc - w / 2, yc - h / 2),
-                    in_source="CV",
-                    to_source="Numpy",
-                    in_relative=True,
-                    to_relative=False,
-                    shape_source="Numpy",
-                    shape=img.shape[:2],
-                )
-                orgs.append(org)
-        img = Box.put_box(
-            img, boxes, in_source="CV", in_format=Box.BoxFormat.XCYC, in_relative=True
-        )
-        img = Box.put_text(img, texts, org=orgs, thickness=3, fontScale=3)
-        show_destroy_cv2(img)
+        boxes = Box.box2box(boxes,
+                            in_format=Box.BoxFormat.XCYC,
+                            to_format=Box.BoxFormat.XYXY,
+                            in_source="CV",
+                            to_source="Numpy",
+                            in_relative=True,
+                            to_relative=False,
+                            shape_source="Numpy",
+                            shape=img.shape[:2],
+                            )
+        img = Box.put_box_text(img, boxes, texts)
+        if show:
+            show_destroy_cv2(img)
         return img
 
     @staticmethod
     def split_dataset(
-        base_dir,
-        out_dir,
-        mode="cp",
-        test_size=0.2,
-        remove_out_dir=False,
-        skip_transfer=True,
-        remove_in_dir=False,
+            base_dir,
+            out_dir,
+            mode="cp",
+            test_size=0.2,
+            remove_out_dir=False,
+            skip_transfer=True,
+            remove_in_dir=False,
     ):
         img_train_names, img_val_names = dir_train_test_split(
             join(base_dir, "images"),
@@ -238,10 +246,9 @@ class YOLOV5TorchObjectDetector(MainClass):
             mode=mode,
             remove_out_dir=remove_out_dir,
             test_size=test_size,
+            remove_in_dir=remove_in_dir
         )
-        img_train_labels = [
-            os.path.splitext(name)[0] + ".txt" for name in img_train_names
-        ]
+        img_train_labels = [os.path.splitext(name)[0] + ".txt" for name in img_train_names]
         img_val_labels = [os.path.splitext(name)[0] + ".txt" for name in img_val_names]
 
         transfer_directory_items(
@@ -251,7 +258,7 @@ class YOLOV5TorchObjectDetector(MainClass):
             mode=mode,
             remove_out_dir=remove_out_dir,
             skip_transfer=skip_transfer,
-            remove_in_dir=remove_in_dir,
+            remove_in_dir=False,  # by removing dir at this point, there would be no data for the next transfer :)
         )
         transfer_directory_items(
             join(base_dir, "labels"),
@@ -262,6 +269,8 @@ class YOLOV5TorchObjectDetector(MainClass):
             skip_transfer=skip_transfer,
             remove_in_dir=remove_in_dir,
         )
+        if remove_in_dir:
+            shutil.rmtree(base_dir)
 
     @staticmethod
     def extract_label(label_path, img_path=None, shape=None, shape_source=None):
@@ -274,7 +283,6 @@ class YOLOV5TorchObjectDetector(MainClass):
 
         if img_path is not None:
             import cv2
-
             shape = cv2.imread(img_path).shape[:2]
             shape_source = "Numpy"
         if shape is not None and shape_source is not None:
@@ -293,18 +301,18 @@ class YOLOV5TorchObjectDetector(MainClass):
 
     @get_from_config
     def detect_dir(
-        self,
-        dir_,
-        confidence=None,
-        iou_thresh=None,
-        classes=None,
-        agnostic=None,
-        img_size=None,
-        extensions=(".png", ".jpg", ".jpeg"),
-        res_img_dir=None,
-        res_label_dir=None,
-        put_annotations=True,
-        remove_dirs=False,
+            self,
+            dir_,
+            confidence=None,
+            iou_thresh=None,
+            classes=None,
+            agnostic=None,
+            img_size=None,
+            extensions=(".png", ".jpg", ".jpeg"),
+            res_img_dir=None,
+            res_label_dir=None,
+            put_annotations=True,
+            remove_dirs=False,
     ):
         import cv2
 
@@ -366,7 +374,7 @@ class YOLOV5TorchObjectDetector(MainClass):
                         )
                         with open(res_path, mode="w") as f:
                             for (b1, b2, b3, b4), class_ in zip(
-                                xcyc_boxes, result["classes"]
+                                    xcyc_boxes, result["classes"]
                             ):
                                 f.write(f"{class_} {b1} {b2} {b3} {b4}\n")
 
@@ -374,80 +382,131 @@ class YOLOV5TorchObjectDetector(MainClass):
 
     @staticmethod
     def clean_samples(label_path, img_path, logger=None, verbose=1):
+        """
+        Using this method, one can remove images and the labels do not have their correspondences.
+        :param label_path:
+        :param img_path:
+        :param logger:
+        :param verbose:
+        :return:
+        """
         c = 0
-        image_names, image_exts = [], []
+        image_names, image_extensions = [], []
         for img in os.listdir(img_path):
             image_name, image_ext = os.path.splitext(img)
             image_names.append(image_name)
-            image_exts.append(image_ext)
-        label_names = [os.path.splitext(l)[0] for l in os.listdir(label_path)]
+            image_extensions.append(image_ext)
 
+        label_names = [os.path.splitext(l)[0] for l in os.listdir(label_path)]
         for label in label_names:
             if label not in image_names:
-                label_path = join(label_path, label + ".txt")
-                log_print(logger, f"Removed {label_path}", verbose=verbose)
-                os.remove(label_path)
+                remove_lbl_path = join(label_path, label + ".txt")
+                log_print(logger, f"Removed {remove_lbl_path}", verbose=verbose)
+                os.remove(remove_lbl_path)
                 c += 1
-        for img_name, img_ext in zip(image_names, image_exts):
+
+        for img_name, img_ext in zip(image_names, image_extensions):
             if img_name not in label_names:
-                image_path = join(img_path, img_name + img_ext)
-                log_print(logger, f"Removed {image_path}", verbose=verbose)
-                os.remove(image_path)
+                remove_img_path = join(img_path, img_name + img_ext)
+                log_print(logger, f"Removed {remove_img_path}", verbose=verbose)
+                os.remove(remove_img_path)
                 c += 1
+
         log_print(logger, f"Removed {c} samples!", verbose=verbose)
 
     @staticmethod
     def combine_datasets(
-        dataset_paths: List[str],
-        final_dataset_path: str,
-        remove_final_dataset: bool = False,
+            dataset_paths: List[str],
+            final_dataset_path: str,
+            remove_final_dataset: bool = False,
+            extra_index_format="prefix"
     ):
         """
 
-        Args:
-            dataset_paths: A list of datasets that should be joined
-            final_dataset_path: path to final dataset
-            remove_final_dataset: whether to remove final dataset path or not!
-
-        Returns:
-
+        :param dataset_paths:
+        :param final_dataset_path:
+        :param remove_final_dataset:
+        :param extra_index_format: whether to add suffix, prefix, or nothing as an extra index to data
+        :return:
         """
-        if remove_final_dataset:
-            remove_create(final_dataset_path)
+        remove_create(final_dataset_path, remove_final_dataset)
+
+        for dataset_path in dataset_paths:
+            YOLOV5TorchObjectDetector.transfer_dataset(dataset_path, final_dataset_path, extra_index_format)
+
+    @staticmethod
+    def transfer_dataset(dataset_path, final_dataset_path, extra_index_format="prefix", mode="cp", logger=None,
+                         verbose=1):
+        """
+        This method is used to transfer samples from a dataset to other one
+        :param dataset_path:
+        :param final_dataset_path:
+        :param extra_index_format:
+        :param mode: Whether copy or move the dataset
+        :param logger:
+        :param verbose:
+        :return:
+        """
+        images_path = os.path.join(dataset_path, "images")
+        labels_path = os.path.join(dataset_path, "labels")
+
         final_images = os.path.join(final_dataset_path, "images")
         final_labels = os.path.join(final_dataset_path, "labels")
 
         os.makedirs(final_images, exist_ok=True)
         os.makedirs(final_labels, exist_ok=True)
 
-        for dataset_path in dataset_paths:
-            images_path = os.path.join(dataset_path, "images")
-            labels_path = os.path.join(dataset_path, "labels")
+        if not os.path.isdir(images_path) or not os.path.isdir(labels_path):
+            log_print(logger, f"{images_path} or {labels_path} do not exit!", verbose=verbose)
+            return
 
-            if os.path.isdir(images_path) and os.path.isdir(labels_path):
-                pass
-            else:
-                print(f"[INFO] {images_path} or {labels_path} do not exit!")
-            # to make sure it's not replicated
-            img_index = len(os.listdir(final_images)) + len(os.listdir(final_labels))
-            img_dict = dict()
-            for img_name in tqdm(
+        # to make sure it's not replicated
+        # index = len(os.listdir(final_images)) + len(os.listdir(final_labels))
+        img_dict = dict()
+        for img_name in tqdm(
                 os.listdir(images_path),
                 total=len(os.listdir(images_path)),
                 desc=f"copying {images_path} to {final_images}",
-            ):
-                img_path = os.path.join(images_path, img_name)
-                new_name = split_extension(img_name, suffix=f"_{img_index}")
-                shutil.copy(img_path, os.path.join(final_images, new_name))
-                img_dict[os.path.splitext(img_name)[0]] = img_index
-                img_index += 1
-            for lbl_name in tqdm(
+        ):
+            img_path = join(images_path, img_name)
+            # new_name = split_extension(img_name, artifact_type=extra_index_format, artifact_value=img_index)
+            new_path = join(final_images, img_name)
+            new_path = file_incremental(new_path, artifact_type=extra_index_format)
+            mv_or_copy(img_path, new_path, mode=mode)
+            # key: original name without extension, val: new name without extension
+            img_dict[split_extension(img_name)[0]] = split_extension(os.path.split(new_path)[-1])[0]
+
+        for lbl_img_bare_name in tqdm(
                 os.listdir(labels_path),
                 total=len(os.listdir(labels_path)),
-                desc=f"copying {labels_path} to {final_labels}",
-            ):
-                lbl_path = os.path.join(labels_path, lbl_name)
-                lbl_index = img_dict.get(os.path.splitext(lbl_name)[0], img_index)
-                new_name = split_extension(lbl_name, suffix=f"_{lbl_index}")
-                shutil.copy(lbl_path, os.path.join(final_labels, new_name))
-                img_index += 1
+                desc=f"copying {labels_path} to {final_labels}"):
+            lbl_path = os.path.join(labels_path, lbl_img_bare_name)
+            lbl_bare_name = split_extension(lbl_img_bare_name)[0]
+            lbl_img_bare_name = img_dict.get(lbl_bare_name, None)
+            if lbl_img_bare_name is None:
+                log_print(logger, f"label: {lbl_img_bare_name} has no image counterpart", verbose=verbose)
+                continue
+            mv_or_copy(lbl_path, os.path.join(final_labels, lbl_img_bare_name + ".txt"), mode=mode)
+        log_print(logger, f"Successfully {mode}-ed {dataset_path} to {final_dataset_path}")
+
+    @staticmethod
+    def rename_labels(labels_dir, rename_dict: dict):
+        """
+        rename labels of a directory of labels based on the input rename dictionary
+        :param labels_dir:
+        :param rename_dict: A dictionary by which the input labels will be renamed
+        :return:
+        """
+        assert os.path.isdir(labels_dir), "The input is not a directory"
+
+        for label_name in os.listdir(labels_dir):
+            if label_name.endswith(".txt"):
+                label_path = join(labels_dir, label_name)
+                with open(label_path, mode='r') as read_file:
+                    labels = []
+                    for line in read_file.readlines():
+                        line = line.strip()
+                        label, *box = line.split(" ")
+                        labels.append(" ".join([str(rename_dict.get(int(label), label)), *box]))
+                with open(label_path, mode='w') as write_file:
+                    write_file.writelines(labels)
